@@ -16,20 +16,20 @@
 */
 
 #include <iostream>
-#include <ignition/transport.hh>
-#include "msgs/stringmsg.pb.h"
+#include <ignition/msgs.hh>
+#include <gz/transport.hh>
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
   // Create a transport node.
-  ignition::transport::Node node;
+  gz::transport::Node node;
 
   // Prepare the input parameters.
-  example::msgs::StringMsg req;
+  gz::msgs::StringMsg req;
   req.set_data("HELLO");
 
-  example::msgs::StringMsg rep;
+  gz::msgs::StringMsg rep;
   bool result;
   unsigned int timeout = 5000;
 
