@@ -16,12 +16,12 @@
 */
 
 #include <iostream>
-#include <ignition/transport.hh>
-#include "msgs/stringmsg.pb.h"
+#include <ignition/msgs.hh>
+#include <gz/transport.hh>
 
 //////////////////////////////////////////////////
 /// \brief Service response callback.
-void responseCb(const example::msgs::StringMsg &_rep, const bool _result)
+void responseCb(const gz::msgs::StringMsg &_rep, const bool _result)
 {
   if (_result)
     std::cout << "Response: [" << _rep.data() << "]" << std::endl;
@@ -33,10 +33,10 @@ void responseCb(const example::msgs::StringMsg &_rep, const bool _result)
 int main(int argc, char **argv)
 {
   // Create a transport node.
-  ignition::transport::Node node;
+  gz::transport::Node node;
 
   // Prepare the input parameters.
-  example::msgs::StringMsg req;
+  gz::msgs::StringMsg req;
   req.set_data("HELLO");
 
   std::cout << "Press <CTRL-C> to exit" << std::endl;
@@ -45,5 +45,5 @@ int main(int argc, char **argv)
   node.Request("/echo", req, responseCb);
 
   // Zzzzzz.
-  ignition::transport::waitForShutdown();
+  gz::transport::waitForShutdown();
 }
