@@ -21,12 +21,10 @@
 #include <sstream>
 #include <string>
 
-namespace ignition::transport::parameters
-{
-// Inline bracket to help doxygen filtering.
-inline namespace IGNITION_TRANSPORT_VERSION_NAMESPACE {
 //////////////////////////////////////////////////
-std::string addIgnMsgsPrefix(const std::string & ignType)
+std::string
+ignition::transport::parameters::addIgnMsgsPrefix(
+  const std::string & ignType)
 {
   std::ostringstream oss{"ign_msgs.", std::ios_base::ate};
   oss << ignType;
@@ -34,7 +32,8 @@ std::string addIgnMsgsPrefix(const std::string & ignType)
 }
 
 //////////////////////////////////////////////////
-std::optional<std::string> getIgnTypeFromAnyProto(
+std::optional<std::string>
+ignition::transport::parameters::getIgnTypeFromAnyProto(
   const google::protobuf::Any & any)
 {
   auto typeUrl = any.type_url();
@@ -49,5 +48,3 @@ std::optional<std::string> getIgnTypeFromAnyProto(
   }
   return ret.substr(sizeof(prefix) - 1);
 }
-}  // namespace IGNITION_TRANSPORT_VERSION_NAMESPACE
-}  // namespace ignition::transport::parameters
