@@ -22,47 +22,56 @@
 #include "gz/transport/AdvertiseOptions.hh"
 #include "gz/transport/Helpers.hh"
 
-namespace ignition::transport
+using namespace gz;
+using namespace transport;
+
+namespace ignition
 {
-inline namespace IGNITION_TRANSPORT_VERSION_NAMESPACE {
-/// \internal
-/// \brief Private data for AdvertiseOptions class.
-class AdvertiseOptionsPrivate
-{
-  /// \brief Constructor.
-  public: AdvertiseOptionsPrivate() = default;
+  namespace transport
+  {
+    inline namespace IGNITION_TRANSPORT_VERSION_NAMESPACE
+    {
+    /// \internal
+    /// \brief Private data for AdvertiseOptions class.
+    class AdvertiseOptionsPrivate
+    {
+      /// \brief Constructor.
+      public: AdvertiseOptionsPrivate() = default;
 
-  /// \brief Destructor.
-  public: virtual ~AdvertiseOptionsPrivate() = default;
+      /// \brief Destructor.
+      public: virtual ~AdvertiseOptionsPrivate() = default;
 
-  /// \brief Default scope value.
-  public: Scope_t scope = Scope_t::ALL;
-};
+      /// \brief Default scope value.
+      public: Scope_t scope = Scope_t::ALL;
+    };
 
-/// \internal
-/// \brief Private data for AdvertiseMessageOptions class.
-class AdvertiseMessageOptionsPrivate
-{
-  /// \brief Constructor.
-  public: AdvertiseMessageOptionsPrivate() = default;
+    /// \internal
+    /// \brief Private data for AdvertiseMessageOptions class.
+    class AdvertiseMessageOptionsPrivate
+    {
+      /// \brief Constructor.
+      public: AdvertiseMessageOptionsPrivate() = default;
 
-  /// \brief Destructor.
-  public: virtual ~AdvertiseMessageOptionsPrivate() = default;
+      /// \brief Destructor.
+      public: virtual ~AdvertiseMessageOptionsPrivate() = default;
 
-  /// \brief Default message publication rate.
-  public: uint64_t msgsPerSec = kUnthrottled;
-};
+      /// \brief Default message publication rate.
+      public: uint64_t msgsPerSec = kUnthrottled;
+    };
 
-/// \internal
-/// \brief Private data for AdvertiseServiceOptions class.
-class AdvertiseServiceOptionsPrivate
-{
-  /// \brief Constructor.
-  public: AdvertiseServiceOptionsPrivate() = default;
+    /// \internal
+    /// \brief Private data for AdvertiseServiceOptions class.
+    class AdvertiseServiceOptionsPrivate
+    {
+      /// \brief Constructor.
+      public: AdvertiseServiceOptionsPrivate() = default;
 
-  /// \brief Destructor.
-  public: virtual ~AdvertiseServiceOptionsPrivate() = default;
-};
+      /// \brief Destructor.
+      public: virtual ~AdvertiseServiceOptionsPrivate() = default;
+    };
+    }
+  }
+}
 
 //////////////////////////////////////////////////
 AdvertiseOptions::AdvertiseOptions()
@@ -216,5 +225,3 @@ bool AdvertiseServiceOptions::operator!=(
 {
   return !(*this == _other);
 }
-}  // namespace IGNITION_TRANSPORT_VERSION_NAMESPACE
-}  // namespace ignition::transport
