@@ -23,8 +23,6 @@
 #pragma warning(pop)
 #endif
 
-#include <google/protobuf/text_format.h>
-
 #include <chrono>
 #include <cstring>
 #include <iostream>
@@ -62,6 +60,8 @@
 #endif
 
 using namespace std::chrono_literals;
+using namespace gz;
+using namespace transport;
 
 const char kIgnAuthDomain[] = "ign-auth";
 
@@ -167,8 +167,6 @@ void sendAuthErrorHelper(zmq::socket_t &_socket, const std::string &_err)
 #endif
 }
 
-namespace ignition::transport
-{
 //////////////////////////////////////////////////
 NodeShared *NodeShared::Instance()
 {
@@ -1321,7 +1319,7 @@ void NodeShared::OnNewRegistration(const MessagePublisher &_pub)
 void NodeShared::OnEndRegistration(const MessagePublisher &_pub)
 {
   // Discard the message if the destination PUUID is not me.
-  if (!_pub.Ctrl().empty() && _pub.Ctrl() != this->pUuid)
+  if (_pub.Ctrl() != this->pUuid)
     return;
 
   std::string topic = _pub.Topic();
@@ -1826,20 +1824,9 @@ void NodeSharedPrivate::PublishThread()
       }
       catch (...)
       {
-        if (std::string str;
-            google::protobuf::TextFormat::PrintToString(
-              *(msgDetails->msgCopy), &str))
-        {
-          std::cerr << "Exception occurred in a local callback "
+        std::cerr << "Exception occurred in a local callback "
           << "on topic [" << msgDetails->info.Topic() << "] with message ["
-          << str << "]" << std::endl;
-        }
-        else
-        {
-          std::cerr << "Exception occurred in a local callback "
-          << "on topic [" << msgDetails->info.Topic() << "]. Unable to show msg"
-          << std::endl;
-        }
+          << msgDetails->msgCopy->DebugString() << "]" << std::endl;
       }
     }
 
@@ -1853,20 +1840,10 @@ void NodeSharedPrivate::PublishThread()
       }
       catch (...)
       {
-        if (std::string str;
-            google::protobuf::TextFormat::PrintToString(
-              *(msgDetails->msgCopy), &str))
-        {
-          std::cerr << "Exception occurred in a local raw callback "
-          << "on topic [" << msgDetails->info.Topic() << "] with message ["
-          << str << "]" << std::endl;
-        }
-        else
-        {
-          std::cerr << "Exception occurred in a local raw callback "
-          << "on topic [" << msgDetails->info.Topic() << "]. Unable to show msg"
+        std::cerr << "Exception occured in a local raw callback "
+          << "on topic [" << msgDetails->info.Topic() << "] with "
+          << "message [" << msgDetails->msgCopy->DebugString() << "]"
           << std::endl;
-        }
       }
     }
   }
@@ -1891,7 +1868,7 @@ void NodeShared::EnableStats(const std::string &_topic, bool _enable,
   }
   else
   {
-    this->dataPtr->enabledTopicStatistics.erase(_topic);
+    this->dataPtr->enabledTopicStatistics.extract(_topic);
     // \todo Also cleanup topicStats.
   }
 }
@@ -1932,4 +1909,3 @@ int NodeSharedPrivate::NonNegativeEnvVar(const std::string &_envVar,
   }
   return numVal;
 }
-}  // namespace ignition::transport
